@@ -4,9 +4,9 @@ from django.db import models as django_models
 def default_cache_func(
         django_model,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
-    redis_model = get_or_create_redis_model_from_django_model(django_model, redis_root)
+    redis_model = create_redis_model_from_django_model(django_model, redis_root)
     redis_dicts = redis_root.get(redis_model, return_dict=True)
     # cache_to_django(
     #     django_model,
@@ -16,7 +16,7 @@ def default_cache_func(
         django_model,
         redis_model,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
     )
 
 
@@ -113,14 +113,14 @@ def django_to_cache(
         django_model,
         redis_model,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
     for django_instance in django_model.objects.all():
         redis_instance = update_or_create_redis_instance_from_django_instance(
             django_instance,
             redis_model,
             redis_root,
-            get_or_create_redis_model_from_django_model
+            create_redis_model_from_django_model
         )
 
 
@@ -128,13 +128,13 @@ def update_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_model,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     redis_dict = django_instance_to_redis_params(
         django_instance,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
     )
 
     if not redis_instance:
@@ -157,7 +157,7 @@ def django_instance_field_to_redis_value(
         django_instance,
         django_field,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
 
     django_field_value = getattr(django_instance, django_field.name)
@@ -167,7 +167,7 @@ def django_instance_field_to_redis_value(
         redis_value = get_or_create_redis_instance_from_django_instance(
             django_foreign_key_instance,
             redis_root,
-            get_or_create_redis_model_from_django_model
+            create_redis_model_from_django_model
         )
 
     elif django_field.__class__ == django_models.ManyToManyField:
@@ -175,7 +175,7 @@ def django_instance_field_to_redis_value(
             get_or_create_redis_instance_from_django_instance(
                 django_many_to_many_instance,
                 redis_root,
-                get_or_create_redis_model_from_django_model
+                create_redis_model_from_django_model
             )
             for django_many_to_many_instance in django_field_value.all()
         ]
@@ -185,17 +185,20 @@ def django_instance_field_to_redis_value(
 def django_instance_to_redis_params(
         django_instance,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
     redis_params = {}
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if not django_field.__class__.__name__.endswith('Rel'):
+            print()
+            print(django_field, django_field.__class__.__name__)
             redis_param = django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
                 redis_root,
-                get_or_create_redis_model_from_django_model
+                create_redis_model_from_django_model
             )
+            print(django_field.name, redis_param)
             redis_params[django_field.name] = redis_param
     return redis_params
 
@@ -203,13 +206,13 @@ def django_instance_to_redis_params(
 def get_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_root,
-        get_or_create_redis_model_from_django_model
+        create_redis_model_from_django_model
 ):
     django_instance_model = django_instance.__class__
-    redis_model = get_or_create_redis_model_from_django_model(django_instance_model, redis_root)
+    redis_model = create_redis_model_from_django_model(django_instance_model, redis_root)
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     if not redis_instance:
-        redis_dict = django_instance_to_redis_params(django_instance, redis_root, get_or_create_redis_model_from_django_model)
+        redis_dict = django_instance_to_redis_params(django_instance, redis_root, create_redis_model_from_django_model)
         redis_model(
             redis_root=redis_root,
             django_id=django_instance.id,
