@@ -15,6 +15,7 @@ class RedisField:
     def __init__(self, default=None, choices=None, null=True, ttl=None):
         self.default = default
         self.value = None
+        check_types(choices, dict)
         self.choices = choices
         self.null = null
         if ttl is not None:
@@ -149,6 +150,7 @@ class RedisForeignKey(RedisNumber):
     def clean(self):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
+            print(self.value)
             self.value = get_ids_from_untyped_data(self.value)
         return super().clean()
 
@@ -270,7 +272,7 @@ class RedisManyToMany(RedisList):
 class RedisBool(RedisNumber):
     
     def __init__(self, *args, **kwargs):
-        kwargs['choices'] = [True, False]
+        kwargs['choices'] = {True: 'Yes', False: 'No'}
         super().__init__(*args, **kwargs)
 
     def clean(self):
@@ -454,7 +456,6 @@ class RedisRoot:
                         redis_field = RedisNumber(null=False)
                     else:
                         redis_field = django_field_to_redis_field(django_field, redis_root)
-                    print(django_field, redis_field)
                     if redis_field:
                         redis_fields[django_field_name] = redis_field
                 return redis_fields
@@ -466,37 +467,6 @@ class RedisRoot:
 
             def django_field_to_redis_field(django_field, redis_root):
 
-                def django_field_params_to_redis_field_params(django_field, redis_root):
-                    allowed_params = ['null', 'default', 'choices', 'remote_field']
-                    allowed_redis_params = {}
-                    for django_field_param_name in django_field.__dict__.keys():
-                        redis_field_param_name = django_field_param_name
-                        if django_field_param_name in allowed_params:
-                            value = getattr(django_field, django_field_param_name)
-                            if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH]:
-                                value = None
-                            if django_field_param_name == 'choices':
-                                real_value = {}
-                                if value is not None:
-                                    for choice in value:
-                                        real_value[choice[0]] = choice[1]
-                                else:
-                                    real_value = None
-                                value = real_value
-                                allowed_redis_params[redis_field_param_name] = value
-                            elif django_field_param_name == 'remote_field':
-                                redis_field_param_name = 'model'
-                                if value is not None:
-                                    value = value.model
-                                    print(django_field_param_name, value)
-                                    value = get_or_create_redis_model_from_django_model(value, redis_root)
-                                    print(django_field_param_name, value)
-                                    if value is not None:
-                                        allowed_redis_params[redis_field_param_name] = value
-                            else:
-                                allowed_redis_params[redis_field_param_name] = value
-                    return allowed_redis_params
-
                 field_mapping = {
                     django_models.BooleanField: RedisBool,
                     django_models.DecimalField: RedisDecimal,
@@ -520,8 +490,6 @@ class RedisRoot:
                     django_models.ManyToManyField: RedisManyToMany
                 }
 
-
-
                 if django_field.__class__.__name__.endswith('Rel'):
                     redis_field = None
                 elif django_field.__class__ in field_mapping.keys():
@@ -538,8 +506,37 @@ class RedisRoot:
 
                     redis_field_params = django_field_params_to_redis_field_params(django_field, redis_root)
                     redis_field = redis_field_class(**redis_field_params)
-                return redis_field            
-            
+                return redis_field
+
+            def django_field_params_to_redis_field_params(django_field, redis_root):
+                allowed_params = ['null', 'default', 'choices', 'remote_field']
+                allowed_redis_params = {}
+                for django_field_param_name in django_field.__dict__.keys():
+                    redis_field_param_name = django_field_param_name
+                    if django_field_param_name in allowed_params:
+                        value = getattr(django_field, django_field_param_name)
+                        if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH]:
+                            value = None
+                        if django_field_param_name == 'choices':
+                            real_value = {}
+                            if value is not None:
+                                for choice in value:
+                                    real_value[choice[0]] = choice[1]
+                            else:
+                                real_value = None
+                            value = real_value
+                            allowed_redis_params[redis_field_param_name] = value
+                        elif django_field_param_name == 'remote_field':
+                            redis_field_param_name = 'model'
+                            if value is not None:
+                                value = value.model
+                                value = get_or_create_redis_model_from_django_model(value, redis_root)
+                                if value is not None:
+                                    allowed_redis_params[redis_field_param_name] = value
+                        else:
+                            allowed_redis_params[redis_field_param_name] = value
+                return allowed_redis_params
+
             def update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root):
                 new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
                 new_registered_models = []
@@ -551,7 +548,11 @@ class RedisRoot:
                 redis_root.registered_models = new_registered_models
                 return new_redis_model
 
-            cache_func(django_model, self, get_or_create_redis_model_from_django_model)
+            cache_func(
+                django_model,
+                self,
+                get_or_create_redis_model_from_django_model
+            )
 
     def _get_connection_pool(self, connection_pool):
         if isinstance(connection_pool, redis.ConnectionPool):
@@ -991,7 +992,6 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
-                    print(field_name, field, field.__class__)
                     cleaned_value = field.clean()
                     if full:
                         field_ttl = self.get_field_ttl(field)
